@@ -1,4 +1,4 @@
-/* $Id: configuration.c,v 1.72 2005/03/28 16:38:34 stpohle Exp $
+/* $Id: configuration.c,v 1.75 2005/04/10 00:22:17 stpohle Exp $
  * configuration */
 
 #include <SDL.h>
@@ -92,6 +92,9 @@ config_init (int argc, char **argv)
     resend_cache.data = NULL;
     resend_cache.fill = -1;
     bman.notifygamemaster = 1;
+	bman.broadcast = 1;
+	bman.dedicated = 0;
+	bman.autostart = AUTOSTART;
     bman.askplayername = 0;
     debug = 0;
     gfx.res.x = 640;
@@ -110,6 +113,7 @@ config_init (int argc, char **argv)
     bman.firewall = 0;
     bman.init_timeout = GAME_TIMEOUT;
     bman.ai_players = 1;
+	bman.minplayers = 0;
     snd.inited = 0;
     snd.audio_rate = 22050;
     snd.audio_format = AUDIO_S16;
@@ -130,39 +134,36 @@ config_init (int argc, char **argv)
 	bman.start_speed = START_SPEED;
 	bman.start_range = START_RANGE;
 	bman.bomb_tickingtime = BOMB_TIMEOUT;
-    bman.dropitemsondeath = 0;
-	
+	bman.dropitemsondeath = 0;
 	d_printf ("\n\n ***** Bomberclone Version %s \n\n", VERSION);
-    if (config_read ()) {       /* error on reading the config file */
-        ReadPrgArgs (argc, argv);
-        gfx_init ();
-        draw_logo ();
-        playernamemenu ();
-    }
-    else {
-        ReadPrgArgs (argc, argv);
-        gfx_init ();
-        draw_logo ();
-        if (bman.askplayername)
-            playermenu ();
-    }
+	config_read ();
+
+    ReadPrgArgs (argc, argv);
+	
+	gfx_init ();
+    draw_logo ();
+	if (bman.askplayername)
+   		playernamemenu ();
 
     snd_init ();
-    gfx_blitdraw ();
-    SDL_Flip (gfx.screen);
+   	gfx_blitdraw ();
+	
+	if (!bman.dedicated)
+		SDL_Flip (gfx.screen);
 
 	sprintf (text,"Bomberclone %s", VERSION);
 	sprintf (icon,"%s/pixmaps/bomberclone.png", bman.datapath);
 	SDL_WM_SetCaption(text , NULL);
 	icon_img = IMG_Load(icon);
 	if (icon_img == NULL)
-			d_printf ("could not load icon. (%s)\n", icon);
+		d_printf ("could not load icon. (%s)\n", icon);
+		
 #ifdef _WIN32
-	{
-		SDL_Surface *tmp = icon_img;
-		icon_img = scale_image (tmp, 32, 32);
-		SDL_FreeSurface (tmp);
-	}
+		{
+			SDL_Surface *tmp = icon_img;
+			icon_img = scale_image (tmp, 32, 32);
+			SDL_FreeSurface (tmp);
+		}
 #endif
 	SDL_WM_SetIcon (icon_img, NULL);
 
@@ -173,8 +174,7 @@ config_init (int argc, char **argv)
 /* read the configuration file
  * return -1 if something went wrong and 0 if no problem */
 int
-config_read ()
-{
+config_read () {
     FILE *config;
     char buf[1024];
     char *findit,
@@ -318,6 +318,9 @@ config_read ()
         if (!strcmp (keyword, "notify")) {
             bman.notifygamemaster = atoi (value);
         }
+        if (!strcmp (keyword, "broadcast")) {
+            bman.broadcast = atoi (value);
+        }
         if (!strcmp (keyword, "ogcserver")) {
             strcpy (bman.ogcserver, value);
         }
@@ -454,6 +457,7 @@ config_write ()
     fprintf (config, "fieldsizex=%d\n", map.size.x);
     fprintf (config, "fieldsizey=%d\n", map.size.y);
     fprintf (config, "notify=%d\n", bman.notifygamemaster);
+    fprintf (config, "broadcast=%d\n", bman.broadcast);
     fprintf (config, "ai_family=%d\n", bman.net_ai_family);
     fprintf (config, "ogcserver=%s\n", bman.ogcserver);
     fprintf (config, "ogc_port=%s\n", bman.ogc_port);
@@ -666,10 +670,13 @@ ReadPrgArgs (int argc, char **argv)
 			printf ("                      (Def.: 11000)\n");
             printf (" -ogcport PORT      - set the local OGC Port (Def.: 11100)\n");
             printf (" -ogc 0/1           - Enable/Disable OGC\n");
+			printf (" -broadcast 0/1     - Enable/Disable broadcast requests.\n");
 			printf (" -host              - start a network game\n");
 			printf (" -join              - go into the join menu\n");
 			printf (" -connect ADDRESS   - connect to a server\n");
 			printf (" -debug 0/1         - enable/disable debug\n");
+			printf (" -dedicated         - run as dedicated server\n");
+			printf (" -autostart SECONDS - time before a game starts\n");
             exit (0);
         }
         if (!strcmp (argv[i], "-port"))
@@ -679,13 +686,23 @@ ReadPrgArgs (int argc, char **argv)
         if (!strcmp (argv[i], "-name"))
             strncpy (bman.playername, argv[++i], LEN_PLAYERNAME);
         if (!strcmp (argv[i], "-name2"))
-            strncpy (bman.player2name, argv[++i], LEN_PLAYERNAME);
-		if (!strcmp (argv[i], "-gamename"))
-			strncpy (bman.gamename, argv[++i], LEN_GAMENAME);
+		strncpy (bman.player2name, argv[++i], LEN_PLAYERNAME);
+	if (!strcmp (argv[i], "-gamename"))
+		strncpy (bman.gamename, argv[++i], LEN_GAMENAME);
         if (!strcmp (argv[i], "-ogc"))
             bman.notifygamemaster = atoi (argv[++i]);
+        if (!strcmp (argv[i], "-broadcast"))
+            bman.broadcast = atoi (argv[++i]);
         if (!strcmp (argv[i], "-debug"))
             debug = atoi (argv[++i]);
+	if (!strcmp (argv[i], "-dedicated")) {
+		if (bman.minplayers <= 1)
+			bman.minplayers = 2;
+		bman.dedicated = 1;
+		printf ("\nDedicated Bomberclone Server - Version " VERSION "\n\n");
+	}
+	if (!strcmp (argv[i], "-autostart"))
+		bman.autostart = atoi (argv[++i]);
     }
 };
 
@@ -710,6 +727,9 @@ ReadPrgArgs_Jump (int argc, char **argv)
 			join_multiplayer_game ();
 		}
 	}
+	
+	if (bman.dedicated > 0)
+		host_multiplayer_game ();
 };
 
 
