@@ -1,4 +1,4 @@
-/* $Id: game.c,v 1.107 2005/02/14 20:09:19 stpohle Exp $ 
+/* $Id: game.c,v 1.111 2005/04/10 00:22:17 stpohle Exp $ 
   game.c - procedures for the game. */
 
 #include <string.h>
@@ -217,24 +217,25 @@ void game_keys_loop () {
 void
 game_loop ()
 {
-    SDL_Event event;
-    int done = 0, eventstate;
+	SDL_Event event;
+	int done = 0, eventstate;
+	int ready_timestamp = 0;
 
-	gfx_blitupdaterectclear ();
-	
-    draw_logo ();
-    draw_field ();
-    if (GT_MP)
-        net_game_fillsockaddr ();
-    SDL_Flip (gfx.screen);
+	if (GT_MP)
+		net_game_fillsockaddr ();
 
 	menu = NULL;
-
     bman.updatestatusbar = 1;   // force an update
     timestamp = SDL_GetTicks (); // needed for time sync.
     d_gamedetail ("GAME START");
-    draw_players ();
 
+	if (!bman.dedicated) {
+		gfx_blitupdaterectclear ();
+	    draw_logo ();
+    	draw_field ();
+	    SDL_Flip (gfx.screen);
+		draw_players ();
+	}
 	
 	if (bman.p_nr >= 0 && bman.p_nr < MAX_PLAYERS) {
 		players[bman.p_nr].ready = 1;
@@ -248,33 +249,56 @@ game_loop ()
 	}
 	
     while (!done && (bman.state == GS_running || bman.state == GS_ready)) {
-        if ((eventstate = SDL_PollEvent (&event)) != 0)
-            switch (event.type) {
-            case (SDL_QUIT):
-                done = 1;
-                bman.state = GS_quit;
-            }
 
-		/*
-		 *	input handling 
-		 */
-		keyb_loop (&event);
+		if (!bman.dedicated) {
+    	    if ((eventstate = SDL_PollEvent (&event)) != 0)
+        	    switch (event.type) {
+            	case (SDL_QUIT):
+                	done = 1;
+	                bman.state = GS_quit;
+    	        }
 
-		game_keys_loop ();
+			/*
+			 *	input handling 
+			 */
+			keyb_loop (&event);
 
-		if (GT_MP)
-			chat_loop (&event);
+			game_keys_loop ();
+
+			if (GT_MP)
+				chat_loop (&event);
 		
-		if ((!IS_LPLAYER2) && (!chat.active))
-			chat_setactive (1, 1);
+			if ((!IS_LPLAYER2) && (!chat.active))
+				chat_setactive (1, 1);
 			
-        restore_players_screen ();
+	        restore_players_screen ();
+		}
+		
+		/* check if we have a dedicated server */
+		if (bman.dedicated && bman.state == GS_ready) {
+			int i, ready = 1;
+			
+			for (i = 0; i < MAX_PLAYERS; i++)
+				if (NET_CANSEND (i) && !players[i].ready)
+					ready = 0;
+			
+			if (ready && ready_timestamp == 0)
+				ready_timestamp = timestamp;
+
+			if (ready && (timestamp - ready_timestamp) > 2500) {
+				bman.state = GS_running;
+				net_send_servermode ();
+			}
+		}
+		
 		
 		player_check (bman.p_nr);			
 		if (IS_LPLAYER2)
 			player_check (bman.p2_nr);
 		
-        dead_playerani ();
+		if (!bman.dedicated)
+	        dead_playerani ();
+		
         special_loop ();
 
 		player_move (bman.p_nr);
@@ -292,9 +316,12 @@ game_loop ()
         bomb_loop ();
         field_loop ();
 		flitems_loop ();
-        draw_players ();
-        game_draw_info ();  // will set the var bman.player_nr
-
+		
+		if (!bman.dedicated) {
+ 	    	draw_players ();
+    	    game_draw_info ();  // will set the var bman.player_nr
+		}
+		
         /* check if there is only one player left and the game is in multiplayer mode
            and if there the last dieing animation is done */
 		if (game_check_endgame () && bman.timeout >= 0.0f)
@@ -305,28 +332,34 @@ game_loop ()
             done = 1;
         }
 		
-        stonelist_draw ();
+		if (!bman.dedicated) {
+	        stonelist_draw ();
 		
-		/* if there is any menu displayed do so */
-		if (menu != NULL) 
-			game_menu_loop (&event, eventstate);
+			/* if there is any menu displayed do so */
+			if (menu != NULL) 
+				game_menu_loop (&event, eventstate);
+		
+	        gfx_blitdraw ();
+		}
 		
-        gfx_blitdraw ();
 		s_calctimesync ();
 		bman.timeout -= timediff;
     }
 
 	if (menu != NULL)
 		menu_delete (menu);
-	gfx_blitdraw ();
 	
-    chat_show (-1, -1, -1, -1);
+	if (!bman.dedicated) {
+		gfx_blitdraw ();
+	
+	    chat_show (-1, -1, -1, -1);
+		draw_logo ();
+		gfx_blitupdaterectclear ();
+		SDL_Flip (gfx.screen);
+	}
 
     d_gamedetail ("GAME END");
     d_printf ("done = %d\n", done);
-	draw_logo ();
-	gfx_blitupdaterectclear ();
-	SDL_Flip (gfx.screen);
 };
 
 
@@ -471,7 +504,7 @@ game_start ()
 {
 	int p, i;
 	
-    menu_displaytext ("Loading..", "Please Wait");
+	if (!bman.dedicated) menu_displaytext ("Loading..", "Please Wait");
 
 	bman.players_nr_s = 0;
 
@@ -527,10 +560,17 @@ game_start ()
 	
 	flitems_reset ();
     init_map_tileset ();
-    tileset_load (map.tileset, -1, -1);
+	
+	if (!bman.dedicated) 
+		tileset_load (map.tileset, -1, -1);
+	
     gfx_load_players (gfx.block.x, gfx.block.y);
-    snd_load (map.tileset);
-	snd_music_start ();	
+	
+	if (!bman.dedicated) {
+	   	snd_load (map.tileset);
+		snd_music_start ();	
+	}
+	
 	map.state = MS_normal;
 	bman.timeout = bman.init_timeout;
 	s_calctimesync (); // to clean up the timesyc 
@@ -629,8 +669,8 @@ void game_showresultteam (int pos_x, int pos_y, int pos_w, int pos_h) {
 	for (t_nr = 0; t_nr < t_count; t_nr++) {
 		sprintf (text, "%s Victorys %d (%d)", tdata[t_nr].team->name, tdata[t_nr].team->wins, tdata[t_nr].team->points);
 		sx = (pos_w - strlen (text) * font[0].size.x) / 2;
-		font_gfxdrawbold (pos_x + sx, pos_y + sy+3, text, 0, COLOR_brown, 1, 1);
-		font_gfxdraw (pos_x + sx, pos_y + sy+3, text, 0, COLOR_yellow, 2);
+		font_gfxdrawbold (10+ pos_x + sx, pos_y + sy+3, text, 0, COLOR_brown, 1, 1);
+		font_gfxdraw (10+ pos_x + sx, pos_y + sy+3, text, 0, COLOR_yellow, 2);
 		sy += SHOWRESULT_TEAMHEAD;
 		dx = pos_w / p_x;
 		sx = (dx - SHOWRESULT_TEAMPLAYERWIDTH)/2;
@@ -651,8 +691,17 @@ void game_showresultteam (int pos_x, int pos_y, int pos_w, int pos_h) {
 				src.y = 0;
 				gfx_blit (tdata[t_nr].pl[p_nr]->gfx->small_image, &src, gfx.screen, &dest, 1);
 			}
+			else {
+				dest.x = pos_x + x;
+				dest.y = pos_y + sy;
+				src.w = dest.w = gfx.ghost_small->w;
+				src.h = dest.h = gfx.ghost_small->h;
+				src.x = 0;
+				src.y = 0;
+				gfx_blit (gfx.ghost_small, &src, gfx.screen, &dest, 1);
+			}
 			sprintf (text, "%s(%d/%d)", tdata[t_nr].pl[p_nr]->name, tdata[t_nr].pl[p_nr]->wins, tdata[t_nr].pl[p_nr]->points);
-			font_gfxdraw (pos_x + x + GFX_SMALLPLAYERIMGSIZE_X*2, pos_y + sy + 2, text, 0, 0, 2);
+			font_gfxdraw (10+ pos_x + x + GFX_SMALLPLAYERIMGSIZE_X*2, pos_y + sy + 2, text, 0, 0, 2);
 			x += dx;
 			col++;
 		}
@@ -718,14 +767,14 @@ void game_showresultnormal (int pos_x, int pos_y, int pos_w, int pos_h) {
 	for (i = 1, p = 0; p < pl_cnt; p++) {
 		if (PS_IS_used (pl[p]->state)) {
 			if (PS_IS_alife (pl[p]->state)) {
-			    font_gfxdrawbold (pos_x + x + GFX_MENUPLAYERIMGSIZE_X + 8, pos_y + y - 10, pl[p]->name, 0, COLOR_brown, 1, 1);
-		    	font_gfxdraw (pos_x + x + GFX_MENUPLAYERIMGSIZE_X + 8,pos_y + y - 10, pl[p]->name, 0, COLOR_yellow, 1);
+			    font_gfxdrawbold (10+ pos_x + x + GFX_MENUPLAYERIMGSIZE_X + 8, pos_y + y - 10, pl[p]->name, 0, COLOR_brown, 1, 1);
+		    	font_gfxdraw (10+ pos_x + x + GFX_MENUPLAYERIMGSIZE_X + 8,pos_y + y - 10, pl[p]->name, 0, COLOR_yellow, 1);
 			}
 			else 
-				font_gfxdraw (pos_x + x + GFX_MENUPLAYERIMGSIZE_X,pos_y + y - 10, pl[p]->name, 0, COLOR_gray, 1);
+				font_gfxdraw (10+ pos_x + x + GFX_MENUPLAYERIMGSIZE_X,pos_y + y - 10, pl[p]->name, 0, COLOR_gray, 1);
 
 			sprintf (text, "%3d (%3d)", pl[p]->wins, pl[p]->points);
-			font_gfxdraw (pos_x + x + GFX_MENUPLAYERIMGSIZE_X, pos_y + y + 6, text, 0, 0, 1);
+			font_gfxdraw (10+ pos_x + x + GFX_MENUPLAYERIMGSIZE_X, pos_y + y + 6, text, 0, 0, 1);
 			
 			if (pl[p]->gfx != NULL) {
 				dest.x = pos_x + x;
@@ -736,6 +785,15 @@ void game_showresultnormal (int pos_x, int pos_y, int pos_w, int pos_h) {
 				src.y = 0;
 				gfx_blit (pl[p]->gfx->menu_image, &src, gfx.screen, &dest, 1);
 			}
+			else {
+				dest.x = pos_x + x;
+				dest.y = pos_y + y - 16;
+				src.w = dest.w = gfx.ghost->w;
+				src.h = dest.h = gfx.ghost->h;
+				src.x = 0;
+				src.y = 0;
+				gfx_blit (gfx.ghost, &src, gfx.screen, &dest, 1);
+			}
 			/* setup the new position */
 			y += (dy / pl_x);
 			x += dx;
