@@ -1,4 +1,4 @@
-/* $Id: gfx.c,v 1.38 2004/09/26 02:28:06 stpohle Exp $ */
+/* $Id: gfx.c,v 1.40 2005/04/09 18:22:40 stpohle Exp $ */
 /* gfx.c */
 
 #include "bomberclone.h"
@@ -6,14 +6,14 @@
 
 _gfx gfx;
 
-static int gfx_get_nr_of_playergfx ();
+int gfx_get_nr_of_playergfx ();
 static void gfx_load_menusmall_players ();
 static void gfx_load_fieldtype_menu ();
 
 /*
  * count all playergfx 
  */
-static int gfx_get_nr_of_playergfx () {
+int gfx_get_nr_of_playergfx () {
 	int i = 0;
 	FILE *f = NULL;
 	char filename[255];
@@ -65,19 +65,24 @@ gfx_load_players (int sx, int sy)
             gfx.players[i].ani.h = sy * 2;
             gfx.players[i].ani.w = (tmpimage->w / 4) * sfkt;
             gfx.players[i].ani.frames = tmpimage->h / GFX_PLAYERIMGSIZE_Y;
-            tmpimage1 =
-                scale_image (tmpimage, gfx.players[i].ani.w * 4,
-                             gfx.players[i].ani.frames * gfx.players[i].ani.h);
-            getRGBpixel (tmpimage1, 0, 0, &r, &g, &b);
-            SDL_SetColorKey (tmpimage1, SDL_SRCCOLORKEY, SDL_MapRGB (tmpimage1->format, r, g, b));
-            gfx.players[i].ani.image = SDL_DisplayFormat (tmpimage1);
-            SDL_FreeSurface (tmpimage1);
+			
+			if (!bman.dedicated) {
+	            tmpimage1 =
+    	            scale_image (tmpimage, gfx.players[i].ani.w * 4,
+        	                     gfx.players[i].ani.frames * gfx.players[i].ani.h);
+            	getRGBpixel (tmpimage1, 0, 0, &r, &g, &b);
+	            SDL_SetColorKey (tmpimage1, SDL_SRCCOLORKEY, SDL_MapRGB (tmpimage1->format, r, g, b));
+	            gfx.players[i].ani.image = SDL_DisplayFormat (tmpimage1);
+    	        SDL_FreeSurface (tmpimage1);
 
-            /* calculate the numbers of images for the animation */
-            gfx.players[i].offset.x = (sx - gfx.players[i].ani.w) / 2;
-            gfx.players[i].offset.y = -sy;
+        	    /* calculate the numbers of images for the animation */
+    	        gfx.players[i].offset.x = (sx - gfx.players[i].ani.w) / 2;
+	            gfx.players[i].offset.y = -sy;
+			}
+			else 
+				gfx.players[i].ani.image = NULL;
 
-            SDL_FreeSurface (tmpimage);
+           	SDL_FreeSurface (tmpimage);
         }
     }
 
@@ -91,46 +96,48 @@ gfx_load_players (int sx, int sy)
     }
 
     gfx.dead.frames = tmpimage->h / (2* GFX_IMGSIZE);
-    tmpimage1 = 
-        scale_image (tmpimage, ((2 * sx * tmpimage->w) / (2 * GFX_IMGSIZE)),
-                     gfx.dead.frames * (2 * sy));
-    getRGBpixel (tmpimage1, 0, 0, &r, &g, &b);
-    SDL_SetColorKey (tmpimage1, SDL_SRCCOLORKEY, SDL_MapRGB (tmpimage1->format, r, g, b));
-    gfx.dead.image = SDL_DisplayFormat (tmpimage1);
-    SDL_FreeSurface (tmpimage1);
-    SDL_FreeSurface (tmpimage);
-
-
-    /* load the illnessthing */
-    sprintf (filename, "%s/player/playersick.png", bman.datapath);
-    tmpimage = IMG_Load (filename);
-    if (tmpimage == NULL) {
-        printf ("Can't load image: %s\n", SDL_GetError ());
-        exit (1);
-    }
-    gfx.ill.frames = tmpimage->h / (2 * GFX_IMGSIZE);
-    tmpimage1 =
-        scale_image (tmpimage, (2 * sx * tmpimage->w) / (2 * GFX_IMGSIZE),
-                     gfx.ill.frames * (2 * sy));
-    getRGBpixel (tmpimage1, 0, 0, &r, &g, &b);
-    SDL_SetColorKey (tmpimage1, SDL_SRCCOLORKEY, SDL_MapRGB (tmpimage1->format, r, g, b));
-    gfx.ill.image = SDL_DisplayFormat (tmpimage1);
-    SDL_FreeSurface (tmpimage);
-    SDL_FreeSurface (tmpimage1);
+	if (!bman.dedicated) {
+		tmpimage1 = 
+	        scale_image (tmpimage, ((2 * sx * tmpimage->w) / (2 * GFX_IMGSIZE)),
+    	                 gfx.dead.frames * (2 * sy));
+	    getRGBpixel (tmpimage1, 0, 0, &r, &g, &b);
+    	SDL_SetColorKey (tmpimage1, SDL_SRCCOLORKEY, SDL_MapRGB (tmpimage1->format, r, g, b));
+	    gfx.dead.image = SDL_DisplayFormat (tmpimage1);
+    	SDL_FreeSurface (tmpimage1);
+	    SDL_FreeSurface (tmpimage);
 
+    	/* load the illnessthing */
+	    sprintf (filename, "%s/player/playersick.png", bman.datapath);
+	    tmpimage = IMG_Load (filename);
+    	if (tmpimage == NULL) {
+        	printf ("Can't load image: %s\n", SDL_GetError ());
+    	   	exit (1);
+	    }
+    	gfx.ill.frames = tmpimage->h / (2 * GFX_IMGSIZE);
+	    tmpimage1 =
+    	    scale_image (tmpimage, (2 * sx * tmpimage->w) / (2 * GFX_IMGSIZE),
+        	             gfx.ill.frames * (2 * sy));
+	    getRGBpixel (tmpimage1, 0, 0, &r, &g, &b);
+    	SDL_SetColorKey (tmpimage1, SDL_SRCCOLORKEY, SDL_MapRGB (tmpimage1->format, r, g, b));
+	    gfx.ill.image = SDL_DisplayFormat (tmpimage1);
+    	SDL_FreeSurface (tmpimage);
+	    SDL_FreeSurface (tmpimage1);
 	
-    /* load the respawn gfx */
-    sprintf (filename, "%s/player/respawn.png", bman.datapath);
-    tmpimage = IMG_Load (filename);
-    if (tmpimage == NULL) {
-        printf ("Can't load image: %s\n", SDL_GetError ());
-        exit (1);
-    }
-    gfx.respawn.frames = tmpimage->h / (2 * GFX_IMGSIZE);
-    gfx.respawn.image  =
-        scale_image (tmpimage, (2 * sx * tmpimage->w) / (2 * GFX_IMGSIZE),
-                     gfx.respawn.frames * (2 * sy)); 
-    SDL_FreeSurface (tmpimage);
+	    /* load the respawn gfx */
+    	sprintf (filename, "%s/player/respawn.png", bman.datapath);
+	    tmpimage = IMG_Load (filename);
+    	if (tmpimage == NULL) {
+        	printf ("Can't load image: %s\n", SDL_GetError ());
+	        exit (1);
+    	}
+	    gfx.respawn.frames = tmpimage->h / (2 * GFX_IMGSIZE);
+    	gfx.respawn.image  =
+        	scale_image (tmpimage, (2 * sx * tmpimage->w) / (2 * GFX_IMGSIZE),
+            	         gfx.respawn.frames * (2 * sy)); 
+	    SDL_FreeSurface (tmpimage);
+	}
+	else
+		SDL_FreeSurface (tmpimage);
 };
 
 
@@ -162,20 +169,23 @@ void
 gfx_init ()
 {
 	int i;
-	
-    if (gfx.fullscreen)
+
+    if (gfx.fullscreen && !bman.dedicated)
         gfx.screen =
             SDL_SetVideoMode (gfx.res.x, gfx.res.y, gfx.bpp,
                               SDL_SWSURFACE | SDL_DOUBLEBUF | SDL_HWACCEL | SDL_FULLSCREEN);
 
-    else
+    else if (!bman.dedicated)
         gfx.screen =
             SDL_SetVideoMode (gfx.res.x, gfx.res.y, gfx.bpp,
                               SDL_SWSURFACE | SDL_DOUBLEBUF | SDL_HWACCEL);
-    if (gfx.screen == NULL) {
+    if (!bman.dedicated && gfx.screen == NULL) {
         d_printf ("Unable to set video mode: %s\n", SDL_GetError ());
         return;
     }
+	else if (bman.dedicated) {
+		gfx.screen = NULL;
+	}
     SDL_ShowCursor (SDL_DISABLE);
 	
 	/* delete small gfx und the menu player gfx */
@@ -333,6 +343,20 @@ static void gfx_load_menusmall_players () {
 			SDL_FreeSurface (img);
 		}
 	}
+	
+	/* load the ghost player */
+	sprintf (filename, "%s/player/ghost.png", bman.datapath);
+	orgimg = IMG_Load (filename);
+	sfkt = (float)(((float)(GFX_MENUPLAYERIMGSIZE_X * 2)) / ((float)orgimg->h));
+	gfx.ghost = scale_image (orgimg, (int)(((float)orgimg->w)*sfkt), GFX_MENUPLAYERIMGSIZE_X * 2);
+	if (gfx.ghost == NULL) {
+     	printf ("Can't load image: %s\n", SDL_GetError ());
+    	exit (1);
+	}
+	sfkt = (float)(((float)(GFX_SMALLPLAYERIMGSIZE_X * 2)) / ((float)orgimg->h));
+	gfx.ghost_small = scale_image (orgimg, (int)(((float)orgimg->w)*sfkt), GFX_SMALLPLAYERIMGSIZE_X * 2);
+
+	SDL_FreeSurface (orgimg);
 }
 
 
@@ -484,6 +508,11 @@ gfx_shutdown ()
 		}
 	}
 	
+	if (gfx.ghost != NULL)
+		SDL_FreeSurface (gfx.ghost);
+	if (gfx.ghost_small != NULL)
+		SDL_FreeSurface (gfx.ghost_small);
+	
 	for (i = 0; i < FT_max; i++) if (gfx.menu_field[i] != NULL) {
 		SDL_FreeSurface (gfx.menu_field[i]);
 		gfx.menu_field[i] = NULL;
@@ -502,6 +531,9 @@ void
 draw_logo ()
 {
 	SDL_Rect dest;
+	
+	if (bman.dedicated) return;
+	
 	dest.x = dest.y = 0;
 	dest.w = gfx.res.x;
 	dest.h = gfx.res.y;
