@@ -1,4 +1,4 @@
-/* $Id: menulists.c,v 1.5 2004/09/12 21:35:32 stpohle Exp $
+/* $Id: menulists.c,v 1.6 2005/03/27 01:31:50 stpohle Exp $
  * Menuhandling: lists */
 
 
@@ -225,7 +225,8 @@ void menu_draw_list (_menuitem *mi) {
 	dest.w = mi->pos.w;
 	dest.h = menulistimages[0][0]->h;
 	
-	if (mi->changed) menu_draw_background ((((_menu *)mi->menu)),&dest);
+	if (mi->changed) 
+		menu_draw_background ((((_menu *)mi->menu)),&dest);
 
 	/* check the focus of the button */
 	if (((_menu *)mi->menu)->focusvis && mi == ((_menu *)mi->menu)->focus)
@@ -270,6 +271,7 @@ void menu_draw_list (_menuitem *mi) {
 		dest.x = MENUOFFSET_X(((_menu *)mi->menu)) + mi->pos.x + mi->pos.w - menulistimages[focus][5]->w;
 		gfx_blit (menulistimages[focus][5], NULL, gfx.screen, &dest, 10000);
 	}
+
 	if (mi->changed) {
 		menu_draw_listbackground (mi, NULL);
 		menu_draw_listtext (mi);
