@@ -1,4 +1,4 @@
-/* $Id: multiwait.c,v 1.54 2004/12/26 04:19:20 stpohle Exp $
+/* $Id: multiwait.c,v 1.55 2005/04/09 18:22:41 stpohle Exp $
    multiwait.c - this manages only the network screen where
    everyone have to select it's players and where even the basic chat is inside
 */
@@ -33,24 +33,30 @@ extern int blitdb_nr;
 static void mw_init ()
 {
 	team_update ();
-	gfx_blitdraw ();
-    draw_logo ();
-	gfx_blitdraw ();
+	if (!bman.dedicated) {
+		gfx_blitdraw ();
+	    draw_logo ();
+		gfx_blitdraw ();
+	}
     bman.updatestatusbar = 1;
 	d_playerdetail ("mw_init:\n");
-	SDL_Flip (gfx.screen);
-    chat_show (10, gfx.res.y / 2, gfx.res.x - 20, gfx.res.y / 2 - 10);
-	chat_setactive (1, 1);
+	if (!bman.dedicated) {
+		SDL_Flip (gfx.screen);
+	    chat_show (10, gfx.res.y / 2, gfx.res.x - 20, gfx.res.y / 2 - 10);
+		chat_setactive (1, 1);
+	}
 };
 
 
 /* free all graphics */
 static void mw_shutdown () {
-    chat_show (-1, -1, -1, -1);
-	gfx_blitdraw ();
-	draw_logo ();
+	if (!bman.dedicated) {
+	    chat_show (-1, -1, -1, -1);
+		gfx_blitdraw ();
+		draw_logo ();
 
-	SDL_Flip (gfx.screen);
+		SDL_Flip (gfx.screen);
+	}
 };
 
 
@@ -214,6 +220,8 @@ static void mw_draw_all_teams () {
 /* the loop itself */
 void wait_for_players () {
     SDL_Event event;
+	int i, cnt, aipl, humanpl_cnt;
+	int timeout_timestamp = timestamp + (bman.autostart * 1000);
 
 	mw_init ();
 
@@ -229,29 +237,54 @@ void wait_for_players () {
 		 * check some little things and do the network stuff
 		 */
 		network_loop ();
-				
+
 		/*
 		 * the drawing stuff
 		 */
-		if (mw_check_screenredraw()) {
-			d_printf ("Draw Status\n");
+		if (!bman.dedicated) {
+			if (mw_check_screenredraw()) {
+				d_printf ("Draw Status\n");
+				gfx_blitdraw ();
+		    	draw_logo ();
+				if (bman.gametype==GT_team) mw_draw_all_teams(); 
+				else mw_draw_all_player ();
+			}
 			gfx_blitdraw ();
-	    	draw_logo ();
-			if (bman.gametype==GT_team) mw_draw_all_teams(); 
-			else mw_draw_all_player ();
-		}
-		gfx_blitdraw ();
 		
-		/*
-		 *	input handling 
-		 */
-		keyb_loop (&event);
-		mw_keys_loop ();
+			/*
+			 *	input handling 
+			 */
+			keyb_loop (&event);
+			mw_keys_loop ();
 
-		chat_loop (&event);
-		chat.active = 1;
+			chat_loop (&event);
+			chat.active = 1;
+		}
+		else {
+			/* check for the minimum of players 	*/
+			
+			for (humanpl_cnt = 0, i = 0, cnt = 0, aipl = -1; i < MAX_PLAYERS; i++) {
+				if (PS_IS_used (players[i].state)) {
+					cnt++;
+					if (PS_IS_aiplayer (players[i].state))
+						aipl = i;
+					else if (players[i].gfx_nr >= 0) 
+						humanpl_cnt++;
+				}
+			}
+			
+			if (cnt < (bman.minplayers+1))
+				single_create_ai (1);
+			
+			if (cnt > (bman.minplayers+1) && aipl >= 0)
+				player_delete (aipl);
+		}
 		
 		s_calctimesync ();
+		
+		if ((bman.autostart > 0) && (timestamp > timeout_timestamp) && bman.dedicated && humanpl_cnt > 0)
+			bman.state = GS_ready;
+		
 	} while (bman.state == GS_wait && bman.sock != -1);
 
     mw_shutdown ();
