@@ -1,4 +1,4 @@
-/* $Id: player.c,v 1.99 2005/02/20 21:58:05 stpohle Exp $
+/* $Id: player.c,v 1.101 2005/04/11 22:21:14 stpohle Exp $
  * player.c - everything what have to do with the player */
 
 #include <SDL.h>
@@ -18,6 +18,9 @@ draw_player (_player * player)
       dest;
     int i;
 
+	if (bman.dedicated)
+		return;
+	
     if ((int)player->pos.x < 0 || (int)player->pos.x >= map.size.x ||
         (int)player->pos.y < 0 || (int)player->pos.y >= map.size.y) {
         d_printf ("FATAL: Draw Player out of range : [%f,%f]\n", player->pos.x,
@@ -548,7 +551,7 @@ player_died (_player * player, signed char dead_by, int network)
 		return;
 		
     // player die !
-    d_printf ("player_died (%10s) current state: %d\n", player->name, player->state);
+    d_printf ("player_died (pl_nr:%d : %10s) current state: %d\n", player - players, player->name, player->state);
 
     bman.updatestatusbar = 1;   // force an update
     if (PS_IS_alife (player->state) && dead_by >= 0 && dead_by < MAX_PLAYERS)
@@ -578,6 +581,9 @@ void
 draw_players ()
 {
     int p;
+	
+	if (bman.dedicated) return;
+	
     for (p = 0; p < MAX_PLAYERS; p++) {
         if (PS_IS_playing (players[p].state) && players[p].tunnelto <= 0)
             draw_player (&players[p]);
@@ -916,7 +922,7 @@ void player_checkdeath (int pnr) {
 	
 	/* if the player is respawning check for finish of the animation 
 	 * reset some data of the player and force update of the status bar */
-    if (PS_IS_respawn (player->state) && player->frame >= 2*gfx.respawn.frames) {
+    if (bman.gametype == GT_deathmatch && PS_IS_respawn (player->state) && player->frame >= 2*gfx.respawn.frames) {
 		d_printf ("Respawn completed for player %s\n", player->name);
 		player->frame = 0;
 		player->state &= (0xFF - PSF_respawn);
